@@ -62,7 +62,7 @@ class verify:
         if logmail in login.text:
             pass
         else:
-            print(notlogin)
+            print('This Mail Is Not Logged In!')
             sys.exit()
         sec="1234567890"
         cod = []
